from setuptools import setup, find_packages, Extension
from setuptools.command.build_ext import build_ext
import os
import subprocess

class BuildExt(build_ext):
    """Custom build extension to compile C shared library"""
    def run(self):
        # Ensure the target directory exists
        build_path = os.path.join(os.path.dirname(__file__), "gsvd")
        os.makedirs(build_path, exist_ok=True)

        # Compile the C code into a shared library
        subprocess.check_call([
            "gcc", "-shared", "-o", os.path.join(build_path, "libgsvd.so"),
            "gsvd/gsvd_wrapper.c", "-fPIC", "-llapacke", "-llapack", "-lblas"
        ])
        build_ext.run(self)

setup(
    name='gsvd',
    version='0.1',
    packages=find_packages(),
    include_package_data=True,
    package_data={'gsvd': ['libgsvd.so']},  # Include compiled shared library
    install_requires=['numpy'],
    author="Harsha Narayana P",
    description="A minimal Python wrapper for GSVD using LAPACKE_dggsvd3",
    cmdclass={'build_ext': BuildExt},  # Use custom build command
)
